@@ -183,7 +183,12 @@ class Mailbox(models.Model):
         msg = self._process_message(message)
         msg.outgoing = False
         msg.save()
-        message_received.send(sender=self, message=msg)
+
+        try:
+            message_received.send(sender=self, message=msg)
+        except:
+            pass
+
         return msg
 
     def record_outgoing_message(self, message):
